import java.util.Vector;
import java.util.Enumeration;

public class Office {
    // OVERVIEW: An Office is a mutable datatype that represents an
    //     office in an election.  A typical Office is:
    //           < name, [ candidate_0, candidate_1, ..., candidate_n-1 ] >
    //     where name is a String and each candidate is a Candidate object.
    //     Candidates are numbered starting from 0.
    
    // Rep:
    private String name;
    private Vector candidates; // Vector of Strings
    
    // Abstraction Function:
    //   AF (r) = < name, candidates > where 
    //      name = r.name
    //      candidates = [ r.candidates[0], ..., r.candidates[r.size() - 1] ]
    //
    // Rep Invariant:
    //   RI (r) = 
    //       name != null
    //       candidates does not contain duplicates
    //           (that is, if candidates[i].equals (candidates[j]) then i
    //            must equal j)
    
    public Office (String n)
	// EFFECTS: Initializes this to < n, [ ] >.
    {
	name = n;
	candidates = new Vector ();
    }
    
    public void addCandidate (String c)
	// MODIFIES: this
	// EFFECTS: Adds candidate c to this.
    {
	candidates.add (c);
    }
    
    public String getName () 
	// EFFECTS: Returns the name of this.
    {
	return name;
    }
    
    public String getCandidate (int i)
	// REQUIRES: i >= 0 and i < the number of candidates in this
	// EFFECTS: Returns the name of candidate i.
    {
	return (String) candidates.get (i); 
    }
    
    public Enumeration candidates () 
	// EFFECTS: Returns an enumeration that produces each candidate of this.
    {
	return ((Vector) candidates.clone ()).elements ();
    }

    public int numberOfCandidates () 
	// EFFECTS: Returns the number of candidates in this.
    {
	return candidates.size ();
    }
}
